===================================
Welcome to Our Python Client Docs
===================================

.. include:: python-client/quickstart.rst
   :start-line: 1
   :end-line: 27

.. include:: python-client/overview.rst
   :start-line: 1
   :end-line: 17

.. toctree::
   :maxdepth: 2
   :caption: Python Client:
   :hidden:

   python-client/installation
   python-client/authentication
   python-client/quickstart
   python-client/overview
   python-client/features
   python-client/usage
   python-client/batching
   python-client/error_handling
   python-client/disk_output
   python-client/async_sync
   python-client/api_biolm
   python-client/api_client
   python-client/rate_limiting
   python-client/faq
   modules.rst

.. toctree::
   :maxdepth: 2
   :caption: REST API:
   :hidden:

   api_docs/index

.. toctree::
   :maxdepth: 2
   :caption: Tutorials & Guides:
   :hidden:

   tutorials_use_cases/notebooks


